@@ -41,6 +41,15 @@
 #define FAUDIODEPRECATED(msg) __attribute__((deprecated(msg)))
 #endif
 
+/* -Wpedantic nameless union/struct silencing */
+#ifndef FAUDIONAMELESS
+#ifdef __GNUC__
+#define FAUDIONAMELESS __extension__
+#else
+#define FAUDIONAMELESS
+#endif /* __GNUC__ */
+#endif /* FAUDIONAMELESS */
+
 #include <stdint.h>
 #include <stddef.h>
 
@@ -455,10 +464,10 @@ extern FAudioGUID DATAFORMAT_SUBTYPE_IEEE_FLOAT;
 
 #define FAUDIO_TARGET_VERSION 8 /* Targeting compatibility with XAudio 2.8 */
 
-#define FAUDIO_ABI_VERSION	0
+#define FAUDIO_ABI_VERSION	 0
 #define FAUDIO_MAJOR_VERSION	19
-#define FAUDIO_MINOR_VERSION	06
-#define FAUDIO_PATCH_VERSION	00
+#define FAUDIO_MINOR_VERSION	 8
+#define FAUDIO_PATCH_VERSION	 0
 
 #define FAUDIO_COMPILED_VERSION ( \
 	(FAUDIO_ABI_VERSION * 100 * 100 * 100) + \
@@ -706,6 +715,20 @@ FAUDIOAPI void FAudio_SetDebugConfiguration(
 	void* pReserved
 );
 
+/* Requests the values that determine's the engine's update size.
+ * For example, a 48KHz engine with a 1024-sample update period would return
+ * 1024 for the numerator and 48000 for the denominator. With this information,
+ * you can determine the precise update size in milliseconds.
+ *
+ * quantumNumerator - The engine's update size, in sample frames.
+ * quantumDenominator - The engine's sample rate, in Hz
+ */
+FAUDIOAPI void FAudio_GetProcessingQuantum(
+	FAudio *audio,
+	uint32_t *quantumNumerator,
+	uint32_t *quantumDenominator
+);
+
 /* FAudioVoice Interface */
 
 /* Requests basic information about a voice.
